Welcome to Mister Softee Ice Cream of Connecticut located at 325 Cherry Street Bridgeport, CT 06605 (203) 367-3000
Description: Mister Softee of Connecticut transforms plain trucks into Americas' most recognizable mobile ice cream vendor
Keywords: ice cream, ice cream truck,vendor,van,ice cream man, good humor,good humour,Food Product Manufacturers, Frozen Desserts bridgeport,connecticut,06605,vending,new england,parties,party,party rental,event rental, event vendor,connecticut,vendor,trucks,rental,weddings,parties,drivers wanted,soft serve,corporate events,kid's birthday party,children,birthday party,where rent ice cream truck,party idea,soft serve,mister softee, mr., mr, mister, softee, softy, connecticut, ct, icecream, ice, cream, softserve, soft, serve, truck, man, fairfield county, bridgeport, fairfield, treats, milkshakes, milk, shakes, cone, cones, birthday, parties, functions, fundraising, events, block, company, government, community, advertising, sundaes, soda, floats, rootbeer, root, beer, banana, splits, social, fresh,Fairfield County, Hartford County,Litchfield County ,New Haven County, New London County, Tolland County,Windham County

Mister Softee of Connecticut
| 203-367-3000

+home +about us +parties +businesses +weddings +contact +inside looking out +drivers wanted +commercial

| View Larger Map

We service all of Fairfield County, Hartford County, Litchfield County, New Haven County, Middlesex County, New London County, Tolland County, and Windham County. If you're in Connecticut, then we service your area!

Please click on the Red Bubble/"A" within the map for directions and more map options.

- Contact Us Name * Address *
  Street Address
  Street Address Line 2
  City | State / Province
  Postal / Zip Code | Country
Phone Number - Area Code Phone Number E-mail * Message * Should be Empty: | Contact Us today for more info by filling out the form or at: Mister Softee of Connecticut phone: 203-367-3000 325 Cherry Street Bridgeport, CT 06605 e-mail: info@mistersofteect.com

Find us on Facebook

©Copyright 2009- 2014 Mister Softee of Connecticut